@@ -2,6 +2,7 @@ from django.urls import path
 from handyhelpers.views import action
 from handyhelpers.views import ajax
 from handyhelpers.views import host
+from handyhelpers.views import htmx
 
 app_name = 'handyhelpers'
 
@@ -24,4 +25,7 @@ urlpatterns = [
     path('host_partition_usage', ajax.get_host_partition_usage, name='host_partition_usage'),
     path('get_host_cpu_stats', ajax.get_host_cpu_stats, name='get_host_cpu_stats'),
 
+    # htmx views
+    path('get_host_processes/', htmx.GetHostProcesses.as_view(), name='get_host_processes'),
+
 ]
